==> openGion6.3.8.5_dev.zip: uap/webapps/gf/db/oracle/sql/install/01_TABLE/GF68S.sql <==
/****************************************************************************/
/* GF68 ( ﾘｿｰｽ計画ﾜｰｸ )                                                     */
/*                                                                          */
/* Created : 2015/09/17 15:31:10                                            */
/****************************************************************************/
CREATE TABLE GF68 (
   RESOURCE_ID  NUMBER   (   9 )                                        /*  10 ﾘｿｰｽID   */
 , SEQ          NUMBER   (   7 )        DEFAULT 0   NOT NULL            /*  20 順       */
 , DYSTART      VARCHAR2 (  14 )                                        /*  30 開始日   */
 , DYDELAY      NUMBER   ( 4,1 )                                        /*  40 開始遅延 */
 , DURATION     NUMBER   ( 4,1 )                                        /*  50 期間     */
 , PRJCODE      VARCHAR2 (  30 )                                        /*  60 PRJｺｰﾄﾞ  */
 , TASK_ID      NUMBER   (   5 )                                        /*  70 ﾀｽｸID    */
 , COMPLETE     NUMBER   (   3 )                                        /*  80 進捗率   */
 , FGTASK       VARCHAR2 (   1 )                                        /*  90 ﾀｽｸ状態F */
 , VAL1         VARCHAR2 ( 100 )                                        /* 100 属性1    */
 , VAL2         VARCHAR2 ( 100 )                                        /* 110 属性2    */
 , VAL3         VARCHAR2 ( 100 )                                        /* 120 属性3    */
 , VAL4         VARCHAR2 ( 100 )                                        /* 130 属性4    */
 , VAL5         VARCHAR2 ( 100 )                                        /* 140 属性5    */
 , UNIQ         NUMBER   (   9 )        DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ          VARCHAR2 (   1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        VARCHAR2 (  14 )                                        /* 820 登録日時 */
 , PGSET        VARCHAR2 (  10 )                                        /* 830 作成PG   */
 , PGPSET       VARCHAR2 (  10 )                                        /* 840 作成親PG */
 , USRSET       VARCHAR2 (  10 )                                        /* 850 作成社員 */
 , DYUPD        VARCHAR2 (  14 )                                        /* 860 更新日時 */
 , PGUPD        VARCHAR2 (  10 )                                        /* 870 更新PG   */
 , PGPUPD       VARCHAR2 (  10 )                                        /* 880 更新親PG */
 , USRUPD       VARCHAR2 (  10 )                                        /* 890 更新者   */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );

CREATE SEQUENCE GF68S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GF68T00 
  BEFORE INSERT ON GF68
  FOR EACH ROW 
  BEGIN 
    SELECT GF68S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/

==> openGion6.4.0.3_dev.zip: uap/webapps/gf/db/oracle/sql/install/01_TABLE/GF68S.sql <==
/****************************************************************************/
/* GF68 ( ﾘｿｰｽ計画ﾜｰｸ )                                                     */
/*                                                                          */
/* Created : 2015/11/16 16:20:03                                            */
/****************************************************************************/
CREATE TABLE GF68 (
   RESOURCE_ID  NUMBER   (   9 )                                        /*  10 ﾘｿｰｽID   */
 , SEQ          NUMBER   (   7 )        DEFAULT 0   NOT NULL            /*  20 順       */
 , DYSTART      VARCHAR2 (  14 )                                        /*  30 開始日   */
 , DYDELAY      NUMBER   ( 4,1 )                                        /*  40 開始遅延 */
 , DURATION     NUMBER   ( 4,1 )                                        /*  50 期間     */
 , PRJCODE      VARCHAR2 (  30 )                                        /*  60 PRJｺｰﾄﾞ  */
 , TASK_ID      NUMBER   (   5 )                                        /*  70 ﾀｽｸID    */
 , COMPLETE     NUMBER   (   3 )                                        /*  80 進捗率   */
 , FGTASK       VARCHAR2 (   1 )                                        /*  90 ﾀｽｸ状態F */
 , VAL1         VARCHAR2 ( 100 )                                        /* 100 属性1    */
 , VAL2         VARCHAR2 ( 100 )                                        /* 110 属性2    */
 , VAL3         VARCHAR2 ( 100 )                                        /* 120 属性3    */
 , VAL4         VARCHAR2 ( 100 )                                        /* 130 属性4    */
 , VAL5         VARCHAR2 ( 100 )                                        /* 140 属性5    */
 , UNIQ         NUMBER   (   9 )        DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ          VARCHAR2 (   1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        VARCHAR2 (  14 )                                        /* 820 登録日時 */
 , PGSET        VARCHAR2 (  10 )                                        /* 830 作成PG   */
 , PGPSET       VARCHAR2 (  10 )                                        /* 840 作成親PG */
 , USRSET       VARCHAR2 (  10 )                                        /* 850 作成社員 */
 , DYUPD        VARCHAR2 (  14 )                                        /* 860 更新日時 */
 , PGUPD        VARCHAR2 (  10 )                                        /* 870 更新PG   */
 , PGPUPD       VARCHAR2 (  10 )                                        /* 880 更新親PG */
 , USRUPD       VARCHAR2 (  10 )                                        /* 890 更新者   */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K NEXT 16K );

CREATE SEQUENCE GF68S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GF68T00 
  BEFORE INSERT ON GF68
  FOR EACH ROW 
  BEGIN 
    SELECT GF68S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/
